const {
  Scene,
  Object3D,
  PerspectiveCamera,
  WebGLRenderer,
  CanvasTexture,
  Sprite,
  SpriteMaterial,
  loadTexture,
  ImageUtils,
  PointLight,
  SpriteAlignment,
  shadowMap,
  BufferGeometry,
  BufferGeometryUtils,
  CubeTextureLoader,
  MultiMaterial
} = THREE;

import {Cube} from './Cube.js';
import { getData } from './getData';
import fragmentShader from './fragmentShader';
import vertexShader from './vertexShader';

// Tweakables
const scaleFactor = 2; // HiDPI
const width = window.innerWidth * scaleFactor;
const height = window.innerHeight * scaleFactor;
const rotationSensitivity = 0.04;
const rotationIncrement = -0.2;




// Returns a color for a given datum and number of clusters.
const camera = new PerspectiveCamera(50, width / height, 1, 1000);
const renderer = new WebGLRenderer({ antialias: true, alpha: true
                                   });

renderer.setSize(width, height);
document.body.appendChild(renderer.domElement);
renderer.domElement.style.width = width / scaleFactor + 'px';
renderer.domElement.style.height = height / scaleFactor + 'px';



var controls = new THREE.OrbitControls(camera, renderer.domElement);


const scene = new Scene();

//GROUND
const groundWidth = 10;
const groundHeight = 10;
var groundTexture = new THREE.TextureLoader().load(
  'https://raw.githubusercontent.com/stemkoski/stemkoski.github.com/master/Three.js/images/checkerboard.jpg'
);
groundTexture.wrapS = groundTexture.wrapT = THREE.RepeatWrapping;
groundTexture.repeat.set(groundWidth/4, groundHeight/4);
var groundMaterial = new THREE.MeshBasicMaterial({
  map: groundTexture,
  side: THREE.DoubleSide
});
var groundGeometry = new THREE.PlaneGeometry(groundWidth, groundHeight);
var ground = new THREE.Mesh(groundGeometry, groundMaterial);
scene.add(ground);

//Pika Dice
//const geometry = new THREE.BoxGeometry(1, 1, 1);
//const loader = new THREE.TextureLoader().load('https://tr.rbxcdn.com/46d884e4194013123a642b61780f3f29/420/420/Decal/Png');
//const material = new THREE.MeshBasicMaterial({map: loader});
//const cube = new THREE.Mesh(geometry, material);
//scene.add(cube);
//const cube2 = new THREE.Mesh(geometry, material);
//scene.add(cube2);




(async () => {
   const data = await getData();

	var cubes = []


  var geo = new THREE.BufferGeometry().fromGeometry(new THREE.BoxGeometry(1, 1, 1))

  
	for ( var i = 0; i < data.length-1100; ++i ) {
    for ( var j = 0; j < parseInt(data[i]['Z'])-100; ++j ) {
    // instead of creating a new geometry, we just clone the bufferGeometry instance
    var geometry = geo.clone();
    geometry.translate(parseInt(data[i]['X']), j, parseInt(data[i]['Y']) );
    // then, we push this bufferGeometry instance in our array
      
    cubes.push(geometry);
    }
  }
console.log(cubes)

  // Here is the big boy in action
  

  var geometriesCubes = THREE.BufferGeometryUtils.mergeBufferGeometries(cubes);
	geometriesCubes.computeBoundingSphere();

  //geometriesCubes.addAttribute( 'color', new THREE.BufferAttribute( 0x0ff000, 3 ) );


  
   


  

	var texture0 = 'https://raw.githubusercontent.com/mrdoob/three.js/dev/examples/textures/minecraft/dirt.png'
	var texture1 = 'https://raw.githubusercontent.com/mrdoob/three.js/dev/examples/textures/minecraft/grass_dirt.png'
  
      const materials = [
        new THREE.MeshBasicMaterial({map: new THREE.TextureLoader().load("https://i.imgur.com/8B1rYNY.png")}),
        new THREE.MeshBasicMaterial({map: new THREE.TextureLoader().load("https://i.imgur.com/8w6LAV6.png")}),
        new THREE.MeshBasicMaterial({map: new THREE.TextureLoader().load("https://i.imgur.com/aVCY4ne.png")}),
        new THREE.MeshBasicMaterial({map: new THREE.TextureLoader().load("https://i.imgur.com/tYOW02D.png")}),
        new THREE.MeshBasicMaterial({map: new THREE.TextureLoader().load("https://i.imgur.com/nVAIICM.png")}),
        new THREE.MeshBasicMaterial({map: new THREE.TextureLoader().load("https://i.imgur.com/EDr3ed3.png")})
    ];

   const loader = new THREE.TextureLoader();

  var materials2 = [
    new THREE.MeshBasicMaterial({map:loader.load( 'https://raw.githubusercontent.com/mrdoob/three.js/dev/examples/textures/minecraft/dirt.png')}),
    new THREE.MeshBasicMaterial({color:0x0ff000}),
    new THREE.MeshBasicMaterial({color:0x0ff000}),
    new THREE.MeshBasicMaterial({color:0x0ff000}),
    new THREE.MeshBasicMaterial({color:0x0ff000}),
    new THREE.MeshBasicMaterial({color:0x0ff000})
  ];
  
  
  

  let uniforms = {
        colorB: {type: 't', value: new THREE.Color(new THREE.TextureLoader().load("https://i.imgur.com/8B1rYNY.png"))},
        sandyTexture: {type: 't', value: new THREE.Color(new THREE.TextureLoader().load("https://i.imgur.com/8B1rYNY.png"))},
        //grassTexture: {type: 't', value: new THREE.Color(new THREE.TextureLoader().load("https://i.imgur.com/8B1rYNY.png"))},
        //rockyTexture: {type: 't', value: new THREE.Color(new THREE.TextureLoader().load("https://i.imgur.com/8B1rYNY.png"))},
        //snowyTexture: {type: 't', value: new THREE.Color(new THREE.TextureLoader().load("https://i.imgur.com/8B1rYNY.png"))},

    }
  
    let material =  new THREE.ShaderMaterial({
    uniforms: uniforms,
    fragmentShader: fragmentShader(),
    vertexShader: vertexShader(),
  })
  
   const mesh = new THREE.Mesh(geometriesCubes,  material );
  scene.add(mesh);
 
  //var faceMaterial = new THREE.MultiMaterial( materials );
  //const loader = new THREE.TextureLoader().load('https://tr.rbxcdn.com/46d884e4194013123a642b61780f3f29/420/420/Decal/Png');
	//const texture =  loader.load( 'https://raw.githubusercontent.com/mrdoob/three.js/master/examples/textures/minecraft/atlas.png')
  //texture.magFilter = THREE.NearestFilter;
  
  
  //scene.add(geometriesCubes );
})()
//Init cube position
//cube.position.z = 0;
//cube.position.x = 0;
//cube.position.y = 0;


//Init ground roration
const epsilon = -0.5;
ground.rotation.x -= Math.PI / 2;
ground.position.z = groundWidth/2 + epsilon;
ground.position.x = groundHeight/2 + epsilon;
ground.position.y = epsilon;

//Init camera position
camera.rotation.x 
  = Math.PI / 2;
camera.position.set(100, 100, 100);

const animate = () => {
    requestAnimationFrame(animate);
 		controls.update();
	  renderer.render(scene, camera);
};
animate();